==> spip_4.0.4.orig.tar.xz: ecrire/lang/public_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=tr
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Ana sayfa', # MODIF
	'articles' => 'Makaleler',
	'articles_auteur' => 'Bu yazarın makaleleri',
	'articles_populaires' => 'En popüler makaleler',
	'articles_rubrique' => 'Bu bölümün makaleleri',
	'aucun_article' => 'Bu adreste makale yok',
	'aucun_auteur' => 'Bu adreste yazar yok',
	'aucun_site' => 'Bu adreste site yok',
	'aucune_breve' => 'Bu adreste kısa haber yok',
	'aucune_rubrique' => 'Bu adreste bölüm yok',
	'autres' => 'Diğer',
	'autres_breves' => 'Diğer kısa haberler',
	'autres_groupes_mots_clefs' => 'Diğer anahtar sözcük grupları',
	'autres_sites' => 'Diğer siteler',

	// B
	'bonjour' => 'Merhaba',

	// C
	'commenter_site' => 'Bu siteye yorum ekle',
	'copie_document_impossible' => 'Belgeyi kopyalamak olanaksız',

	// D
	'date' => 'Tarih',
	'dernier_ajout' => 'Son eklenen',
	'dernieres_breves' => 'Son eklenen kısa haberler',
	'derniers_articles' => 'Son eklenen makaleler',
	'derniers_commentaires' => 'Son eklenen yorumlar',
	'derniers_messages_forum' => 'Forumlarda yayınlanan son mesajlar',

	// E
	'edition_mode_texte' => 'Metin şeklinde değiştir',
	'en_reponse' => 'Yanıttır :',
	'en_resume' => 'Özet',
	'envoyer_message' => 'Bir mesaj gönder',
	'espace_prive' => 'Özel alan',

	// F
	'formats_acceptes' => 'Kabûl edilen biçemler : @formats@.',

	// H
	'hierarchie_site' => 'Site hiyerarşisi',

	// J
	'jours' => 'gün',

	// L
	'lien_connecter' => 'Bağlan',

	// M
	'meme_auteur' => 'Aynı yazardan',
	'meme_rubrique' => 'Aynı bölümde',
	'memes_auteurs' => 'Aynı yazarlardan',
	'message' => 'İleti',
	'messages_forum' => 'Forum mesajları', # MODIF
	'messages_recents' => 'Son forum mesajları',
	'mots_clefs' => 'Anahtar sözcük',
	'mots_clefs_meme_groupe' => 'Aynı grupta anahtar sözcük',

	// N
	'navigation' => 'Gezinti',
	'nom' => 'Soyadı',
	'nouveautes' => 'Yenilikler',
	'nouveautes_web' => 'Web’deki yenilikler',
	'nouveaux_articles' => 'Yeni makaleler',
	'nouvelles_breves' => 'Yeni kısa haberler',

	// P
	'page_precedente' => 'önceki sayfa',
	'page_suivante' => 'sonraki sayfa',
	'par_auteur' => 'yazan',
	'participer_site' => 'Bu siteye katkıda bulunabilir ve aşağıya kayıt olarak kendi makalelerinizi önerebilirsiniz. Bu durumda hemen sitenin özel alanına girmenizi sağlayacak kodları içeren bir mesaj alırsınız.',
	'plan_site' => 'Site planı',
	'popularite' => 'Popülerlik',
	'poster_message' => 'Bir mesaj gönder',
	'proposer_site' => 'Bu bölüme eklenecek bir site önerebilirsiniz :',

	// R
	'repondre_article' => 'Bu makaleyi yanıtla',
	'repondre_breve' => 'Bu kısa haberi yanıtla',
	'resultats_recherche' => 'Arama sonuçları',
	'retour_debut_forums' => 'Forumların başına dön',
	'rubrique' => 'Bölüm',
	'rubriques' => 'Bölümler',

	// S
	'signatures_petition' => 'İmzalar',
	'site_realise_avec_spip' => 'SPIP ile gerçekleştirilmiş site',
	'sites_web' => 'web sitesi',
	'sous_rubriques' => 'Alt-bölümler',
	'spam' => 'Spam',
	'suite' => 'devamı',
	'sur_web' => 'Web’de',
	'syndiquer_rubrique' => 'Bu bölümü paylaş',
	'syndiquer_site' => 'Tüm siteyi paylaş',

	// T
	'texte_lettre_information' => 'Sitenin bilgilendirme mektubu',
	'texte_lettre_information_2' => 'Bu mektup belirtilen tarihten beri eklenen makale ve kısa haberleri listeler', # MODIF

	// V
	'ver_imprimer' => 'Basılacak sürüm',
	'voir_en_ligne' => 'Çevrimiçi görüntüle',
	'voir_squelette' => 'bu sayfanın iskeletini göster'
);

==> spip_4.4.9+dfsg.orig.tar.xz: ecrire/lang/public_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=tr
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Ana sayfa', # MODIF
	'articles' => 'Makaleler',
	'articles_auteur' => 'Bu yazarın makaleleri',
	'articles_populaires' => 'En popüler makaleler',
	'articles_rubrique' => 'Bu bölümün makaleleri',
	'aucun_article' => 'Bu adreste makale yok',
	'aucun_auteur' => 'Bu adreste yazar yok',
	'aucun_site' => 'Bu adreste site yok',
	'aucune_breve' => 'Bu adreste kısa haber yok',
	'aucune_rubrique' => 'Bu adreste bölüm yok',
	'autres' => 'Diğer',
	'autres_breves' => 'Diğer kısa haberler',
	'autres_groupes_mots_clefs' => 'Diğer anahtar sözcük grupları',
	'autres_sites' => 'Diğer siteler',

	// B
	'bonjour' => 'Merhaba',

	// C
	'commenter_site' => 'Bu siteye yorum ekle',
	'copie_document_impossible' => 'Belgeyi kopyalamak olanaksız',

	// D
	'date' => 'Tarih',
	'dernier_ajout' => 'Son eklenen',
	'dernieres_breves' => 'Son eklenen kısa haberler',
	'derniers_articles' => 'Son eklenen makaleler',
	'derniers_commentaires' => 'Son eklenen yorumlar',
	'derniers_messages_forum' => 'Forumlarda yayınlanan son mesajlar',

	// E
	'edition_mode_texte' => 'Metin şeklinde değiştir',
	'en_reponse' => 'Yanıttır :',
	'en_resume' => 'Özet',
	'envoyer_message' => 'Bir mesaj gönder',
	'espace_prive' => 'Özel alan',

	// F
	'formats_acceptes' => 'Kabûl edilen biçemler : @formats@.',

	// H
	'hierarchie_site' => 'Site hiyerarşisi',

	// J
	'jours' => 'gün',

	// L
	'lien_connecter' => 'Bağlan',

	// M
	'meme_auteur' => 'Aynı yazardan',
	'meme_rubrique' => 'Aynı bölümde',
	'memes_auteurs' => 'Aynı yazarlardan',
	'message' => 'İleti',
	'messages_forum' => 'Forum mesajları', # MODIF
	'messages_recents' => 'Son forum mesajları',
	'mots_clefs' => 'Anahtar sözcük',
	'mots_clefs_meme_groupe' => 'Aynı grupta anahtar sözcük',

	// N
	'navigation' => 'Gezinti',
	'nom' => 'Soyadı',
	'nouveautes' => 'Yenilikler',
	'nouveautes_web' => 'Web’deki yenilikler',
	'nouveaux_articles' => 'Yeni makaleler',
	'nouvelles_breves' => 'Yeni kısa haberler',

	// P
	'page_precedente' => 'önceki sayfa',
	'page_suivante' => 'sonraki sayfa',
	'par_auteur' => 'yazan',
	'participer_site' => 'Bu siteye katkıda bulunabilir ve aşağıya kayıt olarak kendi makalelerinizi önerebilirsiniz. Bu durumda hemen sitenin özel alanına girmenizi sağlayacak kodları içeren bir mesaj alırsınız.',
	'plan_site' => 'Site planı',
	'popularite' => 'Popülerlik',
	'poster_message' => 'Bir mesaj gönder',
	'proposer_site' => 'Bu bölüme eklenecek bir site önerebilirsiniz :',

	// R
	'repondre_article' => 'Bu makaleyi yanıtla',
	'repondre_breve' => 'Bu kısa haberi yanıtla',
	'resultats_recherche' => 'Arama sonuçları',
	'retour_debut_forums' => 'Forumların başına dön',
	'rubrique' => 'Bölüm',
	'rubriques' => 'Bölümler',

	// S
	'signatures_petition' => 'İmzalar',
	'site_realise_avec_spip' => 'SPIP ile gerçekleştirilmiş site',
	'sites_web' => 'web sitesi',
	'sous_rubriques' => 'Alt-bölümler',
	'spam' => 'Spam',
	'suite' => 'devamı',
	'sur_web' => 'Web’de',
	'syndiquer_rubrique' => 'Bu bölümü paylaş',
	'syndiquer_site' => 'Tüm siteyi paylaş',

	// T
	'texte_lettre_information' => 'Sitenin bilgilendirme mektubu',
	'texte_lettre_information_2' => 'Bu mektup belirtilen tarihten beri eklenen makale ve kısa haberleri listeler', # MODIF

	// V
	'ver_imprimer' => 'Basılacak sürüm',
	'voir_en_ligne' => 'Çevrimiçi görüntüle',
	'voir_squelette' => 'bu sayfanın iskeletini göster',
];
